//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// Class          : Model
//
// Author         : Richard E. Pattis
//                  Computer Science Department
//                  Carnegie Mellon University
//                  5000 Forbes Avenue
//                  Pittsburgh, PA 15213-3891
//                  e-mail: pattis@cs.cmu.edu
//
// Maintainer     : Author
//
//
// Description:
//
//   The Model class defines a minimal set of methods that are called by the
// Controller class to push data. It defines one method (pullPress) to pull
// data from the Controller class.
//
//   Note that "no access modifier" means that the method is package
// friendly: this means the member is public to all other classes in
// the ControllerDemo package, but private elsewhere.
//
// Future Plans   : None
//
// Program History:
//   3/19/02: R. Pattis - Operational for 15-100/15-111
//
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////



package controllerDemo;



public class Model
{

  //We could let Java write the default (trivial) constructor since
  //  this class declares no instances variables to be initialized
  public Model ()
  {}



  //Refer to the Controller
	public void addController(Controller c)
	{controller = c;}

	
	
	//The stub methods (except pullPress)
	
  void buttonPress(String text)
  {System.out.println("Debug-Model: buttonPress = " + text + "\n");}
        
  void textFieldEntered(String id, String text)
  {System.out.println("Debug-Model: "+id+" textFieldEntered = " + text + "\n");}
        
  void decisionPanelUpdate(String text)
  {System.out.println("Debug-Model: decisionPanelUpdate = " + text + "\n");}

  void weatherPanelUpdate(String text)
  {System.out.println("Debug-Model: weatherPanelUpdate = " + text + "\n");}

  void rainPanelUpdate(double percent)
  {System.out.println("Debug-Model: rainPanelUpdate = " + percent + "\n");}

  void mouseClick(int x, int y, int clickCount)
  { System.out.println("Debug-Model: mouseClick = ("+x+","+y+")x"+clickCount + "\n");}
  
  void keyTyped(char key)
  {System.out.println("Debug-Model: keyTyped = " + key + "\n");}



  //Pulls information from decisionPanel, weatherPanel, and rainPanel
  void pullPress()
  {
    System.out.println("Debug-Model: decision pulled value = " +
       controller.decisionPanel.getSelectedValue());
    System.out.println("Debug-Model: weather pulled value = " +
       controller.weatherPanel.getSelectedValue());
    System.out.println("Debug-Model: rainy slider pulled value = " +
       controller.rainPanel.getSelectedValue() + "\n");
  }

  
  //instance variables
  Controller controller;
}


