//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// Class          : PercentSliderPanel
//
// Author         : Richard E. Pattis
//                  Computer Science Department
//                  Carnegie Mellon University
//                  5000 Forbes Avenue
//                  Pittsburgh, PA 15213-3891
//                  e-mail: pattis@cs.cmu.edu
//
// Maintainer     : Author
//
//
// Description:
//
//   Builds a JPanel containing a labeled slider, going from 0% to 100%
// (with labels in increments of 10). Objects in this class push/pull a
// double value in the range [0.,1.].
//
// Pushing is when the control calls the model to tell it about a new value.
// Pulling is when the model calls the control asking it for its current value.
//
//   Sometimes Java requires "final" parameters/variables to get a job done. This
// just ensures that the object the variable stores never changes. If Java requires
// "final" for an obscure reason, the compiler will be pretty specific about it.
//
//   Note that "no access modifier" means that the method is package
// friendly: this means the member is public to all other classes in
// the ControllerDemo package, but private elsewhere.
//
// Future Plans   : More Comments
//
// Program History:
//   3/19/02: R. Pattis - Operational for 15-100/15-111
//
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////



package controllerDemo;


import javax.swing.event.ChangeListener;
import javax.swing.event.ChangeEvent;

import java.awt.FlowLayout;

import javax.swing.BoxLayout;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSlider;

import java.util.Hashtable;


class PercentSliderPanel extends JPanel
{

   public PercentSliderPanel(String label, final ChangeListener change)
   {
     super();
     ((FlowLayout)getLayout()).setAlignment(FlowLayout.LEFT);
     
     selectedValue = 50;
     
     final JSlider slider = new JSlider(JSlider.HORIZONTAL,0,100,selectedValue);
     
     //Set appearance of Slider
     slider.setMajorTickSpacing(10);
     slider.setMinorTickSpacing( 1);
     slider.setPaintTicks (true);
     slider.setPaintLabels(true);
     
     //Put in pairs of index/labels
     Hashtable labelTable = new Hashtable();
     for (int i=0; i<=100; i+=10)
         labelTable.put( new Integer(i), new JLabel(""+i) );
     slider.setLabelTable(labelTable);
     
     //Always prints a debug message and stores state of slider
     //Specify how all changes are pushed via the parameter "change"
     slider.addChangeListener( new ChangeListener()
       {public void stateChanged(ChangeEvent e)
         {
           System.out.println("Debug-Controller: " + "PercentSliderPanel: " +
		                          slider.getValue());
 		       //System.out.println("  Change-Event = " + e);
           selectedValue = slider.getValue();
           if (change != null)
             change.stateChanged(e);
         }
       });
       
      add(new JLabel(label));
      add(slider);

     }
  
  
  //Allow to pull data when required
  double getSelectedValue()
  {return (double)selectedValue/100.;}



  //intance variable for pulled data
  private int selectedValue;

}


