//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// Class          : View
//
// Author         : Richard E. Pattis
//                  Computer Science Department
//                  Carnegie Mellon University
//                  5000 Forbes Avenue
//                  Pittsburgh, PA 15213-3891
//                  e-mail: pattis@cs.cmu.edu
//
// Maintainer     : Author
//
//
// Description:
//
//   This View class builds a simple BoxLayout view (Y_AXIS) of the
// components provided by the Controller class. In a real GUI, all
// sorts of interesting things would be done here (see the Layout Lab),
// but in this GUI, we focus on the controller.
//
//   Note that "no access modifier" means that the method is package
// friendly: this means the member is public to all other classes in
// the ControllerDemo package, but private elsewhere.
// Future Plans   : More Layouts; more components
//
// Program History:
//   3/20/02: R. Pattis - Operational for 15-100/15-111
//
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////


package controllerDemo;


//Frame and Panel (Multiple panels are the workhorses for layouts)
import javax.swing.BorderFactory;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JButton;
import javax.swing.JTextArea;
import javax.swing.JScrollPane;

//Layouts (which can added to Panels, to control the components added)
import java.awt.BorderLayout;
import javax.swing.BoxLayout;
import java.awt.FlowLayout;
import java.awt.GridLayout;

//Miscellaneous
import java.awt.Component;
import java.awt.Container;

//Real miscellaneous
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;


public class View extends JFrame
{

  //We could let Java write the default (trivial) constructor since
  //  this class declares no instances variables to be initialized
	public View()
	{}
	
	
	
  //Refer to the Controller
	public void addController(Controller c)
	{controller = c;}

	
	
  //build does the heavy lifting; it builds the view, populating it
  //  with the appropriate components
  //GUI applications have lots of little details to specify to make
  //  them look nice, and this method is in charge of them all
	public void build()
	{
	  //When a window close icon is pressed, exit the entire program
		addWindowListener(new WindowAdapter() {
			public void windowClosing(WindowEvent e)
			{System.exit(0);}
		});
		
		
		//Label the JFrame
		setTitle("Controller Lab");
		
		//Create a JPanel and add components to it				
    JPanel all = new JPanel();    
    all.setLayout(new BoxLayout(all,BoxLayout.Y_AXIS));
    
    //Buttons
    all.add(controller.getButton("B1"));
    all.add(controller.getSwitchingButton(new String[]{"first","second","third"}));

    //Text fields
    all.add(controller.getTextField("tf1","Initial 1",30));
    all.add(controller.getTextField("tf2","Initial 2",30));

    //Radio Buttons
    all.add(controller.getDecisionPanel(new String[]{"Yes", "No", "Maybe So"}));
    
    //Radio Buttons, but with a grid layout, and the JPanel having a border
    JPanel weather = controller.getWeatherPanel (new String[]{"Sunny", "Overcast", "Rainy", "Snow"});
    weather.setLayout(new GridLayout(2,2));
    weather.setBorder(BorderFactory.createEtchedBorder());
    all.add(weather);

    //Text area in a scrollable pane
    JTextArea stuff = new JTextArea(5,30);
    all.add(new JScrollPane(stuff));
    stuff.append("Line 1\n");
    stuff.append("Line 2\n");
    stuff.append("Line 3\n");
    stuff.append("Line 4\n");
    stuff.append("Line 5\n");
    stuff.append("Line 6\n");
    stuff.append("Line 7\n");
    
    //Slider
    all.add(controller.getRainSlider("Chance of Rain"));
    
    //Button to pull values
    all.add(controller.getPullButton("Pull Values from Radio Buttons/Slider"));
    
    
    //Add a mouse listener to the JPanel
    all.addMouseListener(controller.getMouseListener(all));

    //add the key listener to the JFrame
    //I know that this method does not work in Java 1.4
    addKeyListener(controller.getKeyListener());
    
    
		Container contentPane = getContentPane();
		contentPane.add(all, "Center");


		//Let the natural size of the components determine the JFrame's size
		//Notice no call to SetSize or SetLocation 
		pack();
  }


  //instance variable to get controller components
  private Controller controller;
}
